==> ejc-proequipmentcorp-impl-3.0.0-20221020.151200-42-sources.jar: com/ejianc/business/proequipmentcorppur/asset/bean/AssetScrapDetailEntity.java <==
package com.ejianc.business.proequipmentcorppur.asset.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.math.BigDecimal;
import java.util.Date;

/**
 * 固定资产报废明细表（设备报废申请子表）
 * 
 * @author generator
 * 
 */
 @TableName("ejc_proequipmentcorp_asset_scrap_detail")
public class AssetScrapDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="scrap_id")
    private Long scrapId; // 主表id
    @TableField(value="equipment_type_id")
    private Long equipmentTypeId; // 设备分类id
    @TableField(value="equipment_type_code")
    private String equipmentTypeCode; // 设备分类编码
    @TableField(value="equipment_type_name")
    private String equipmentTypeName; // 设备分类名称
    @TableField(value="equipment_id")
    private Long equipmentId; // 设备id
    @TableField(value="equipment_code")
    private String equipmentCode; // 设备编码
    @TableField(value="equipment_name")
    private String equipmentName; // 设备名称
    @TableField(value="asset_id")
    private Long assetId; // 资产id
    @TableField(value="asset_code")
    private String assetCode; // 资产编码
    @TableField(value="asset_name")
    private String assetName; // 资产名称
    @TableField(value="finance_asset_id")
    private Long financeAssetId; // 财务资产id
    @TableField(value="finance_asset_code")
    private String financeAssetCode; // 财务资产编码
    @TableField(value="spec")
    private String spec; // 规格型号
    @TableField(value="unit_id")
    private Long unitId; // 计量单位 Id
    @TableField(value="unit")
    private String unit; // 计量单位
    @TableField(value="use_unit_id")
    private Long useUnitId; // 使用单位id
    @TableField(value="use_unit")
    private String useUnit; // 使用单位
    @TableField(value="leave_factory_date")
    private Date leaveFactoryDate; // 设备出厂日期
    @TableField(value="original_value")
    private BigDecimal originalValue; // 原值(无税)
    @TableField(value="original_value_tax")
    private BigDecimal originalValueTax; // 原值(含税)
    @TableField(value="net_worth")
    private BigDecimal netWorth; // 净值(无税)
    @TableField(value="net_worth_tax")
    private BigDecimal netWorthTax; // 净值(含税)
    @TableField(value="original_value_price")
    private BigDecimal originalValuePrice; // 原值单价(无税)
    @TableField(value="original_value_price_tax")
    private BigDecimal originalValuePriceTax; // 原值单价(含税)
    @TableField(value="residual_value_tax")
    private BigDecimal residualValueTax; // 残值(含税)
    @TableField(value="residual_value")
    private BigDecimal residualValue; // 残值(无税)
    @TableField(value="last_depreciation_mny")
    private BigDecimal lastDepreciationMny; // 累计折旧金额
    @TableField(value="last_depreciation_tax_mny")
    private BigDecimal lastDepreciationTaxMny; // 累计折旧金额（含税）
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="property_unit_id")
    private Long propertyUnitId; // 产权单位id
    @TableField(value="property_unit")
    private String propertyUnit; // 产权单位
    @TableField(value="manage_unit_id")
    private Long manageUnitId; // 管理单位id
    @TableField(value="manage_unit")
    private String manageUnit; // 管理单位
    
    

    public Long getScrapId() {
        return scrapId;
    }

    public void setScrapId(Long scrapId) {
        this.scrapId = scrapId;
    }
    public Long getEquipmentTypeId() {
        return equipmentTypeId;
    }

    public void setEquipmentTypeId(Long equipmentTypeId) {
        this.equipmentTypeId = equipmentTypeId;
    }
    public String getEquipmentTypeCode() {
        return equipmentTypeCode;
    }

    public void setEquipmentTypeCode(String equipmentTypeCode) {
        this.equipmentTypeCode = equipmentTypeCode;
    }
    public String getEquipmentTypeName() {
        return equipmentTypeName;
    }

    public void setEquipmentTypeName(String equipmentTypeName) {
        this.equipmentTypeName = equipmentTypeName;
    }
    public Long getEquipmentId() {
        return equipmentId;
    }

    public void setEquipmentId(Long equipmentId) {
        this.equipmentId = equipmentId;
    }
    public String getEquipmentCode() {
        return equipmentCode;
    }

    public void setEquipmentCode(String equipmentCode) {
        this.equipmentCode = equipmentCode;
    }
    public String getEquipmentName() {
        return equipmentName;
    }

    public void setEquipmentName(String equipmentName) {
        this.equipmentName = equipmentName;
    }
    public Long getAssetId() {
        return assetId;
    }

    public void setAssetId(Long assetId) {
        this.assetId = assetId;
    }
    public String getAssetCode() {
        return assetCode;
    }

    public void setAssetCode(String assetCode) {
        this.assetCode = assetCode;
    }
    public String getAssetName() {
        return assetName;
    }

    public void setAssetName(String assetName) {
        this.assetName = assetName;
    }
    public Long getFinanceAssetId() {
        return financeAssetId;
    }

    public void setFinanceAssetId(Long financeAssetId) {
        this.financeAssetId = financeAssetId;
    }
    public String getFinanceAssetCode() {
        return financeAssetCode;
    }

    public void setFinanceAssetCode(String financeAssetCode) {
        this.financeAssetCode = financeAssetCode;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public Long getUnitId() {
        return unitId;
    }

    public void setUnitId(Long unitId) {
        this.unitId = unitId;
    }
    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }
    public Long getUseUnitId() {
        return useUnitId;
    }

    public void setUseUnitId(Long useUnitId) {
        this.useUnitId = useUnitId;
    }
    public String getUseUnit() {
        return useUnit;
    }

    public void setUseUnit(String useUnit) {
        this.useUnit = useUnit;
    }
    public Date getLeaveFactoryDate() {
        return leaveFactoryDate;
    }

    public void setLeaveFactoryDate(Date leaveFactoryDate) {
        this.leaveFactoryDate = leaveFactoryDate;
    }
    public BigDecimal getOriginalValue() {
        return originalValue;
    }

    public void setOriginalValue(BigDecimal originalValue) {
        this.originalValue = originalValue;
    }
    public BigDecimal getOriginalValueTax() {
        return originalValueTax;
    }

    public void setOriginalValueTax(BigDecimal originalValueTax) {
        this.originalValueTax = originalValueTax;
    }
    public BigDecimal getNetWorth() {
        return netWorth;
    }

    public void setNetWorth(BigDecimal netWorth) {
        this.netWorth = netWorth;
    }
    public BigDecimal getNetWorthTax() {
        return netWorthTax;
    }

    public void setNetWorthTax(BigDecimal netWorthTax) {
        this.netWorthTax = netWorthTax;
    }
    public BigDecimal getOriginalValuePrice() {
        return originalValuePrice;
    }

    public void setOriginalValuePrice(BigDecimal originalValuePrice) {
        this.originalValuePrice = originalValuePrice;
    }
    public BigDecimal getOriginalValuePriceTax() {
        return originalValuePriceTax;
    }

    public void setOriginalValuePriceTax(BigDecimal originalValuePriceTax) {
        this.originalValuePriceTax = originalValuePriceTax;
    }
    public BigDecimal getResidualValueTax() {
        return residualValueTax;
    }

    public void setResidualValueTax(BigDecimal residualValueTax) {
        this.residualValueTax = residualValueTax;
    }
    public BigDecimal getResidualValue() {
        return residualValue;
    }

    public void setResidualValue(BigDecimal residualValue) {
        this.residualValue = residualValue;
    }
    public BigDecimal getLastDepreciationMny() {
        return lastDepreciationMny;
    }

    public void setLastDepreciationMny(BigDecimal lastDepreciationMny) {
        this.lastDepreciationMny = lastDepreciationMny;
    }
    public BigDecimal getLastDepreciationTaxMny() {
        return lastDepreciationTaxMny;
    }

    public void setLastDepreciationTaxMny(BigDecimal lastDepreciationTaxMny) {
        this.lastDepreciationTaxMny = lastDepreciationTaxMny;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    public Long getPropertyUnitId() {
        return propertyUnitId;
    }

    public void setPropertyUnitId(Long propertyUnitId) {
        this.propertyUnitId = propertyUnitId;
    }

    public String getPropertyUnit() {
        return propertyUnit;
    }

    public void setPropertyUnit(String propertyUnit) {
        this.propertyUnit = propertyUnit;
    }

    public Long getManageUnitId() {
        return manageUnitId;
    }

    public void setManageUnitId(Long manageUnitId) {
        this.manageUnitId = manageUnitId;
    }

    public String getManageUnit() {
        return manageUnit;
    }

    public void setManageUnit(String manageUnit) {
        this.manageUnit = manageUnit;
    }
}

==> ejc-proequipmentcorp-impl-3.0.0-20230525.035006-412-sources.jar: com/ejianc/business/proequipmentcorppur/asset/bean/AssetScrapDetailEntity.java <==
package com.ejianc.business.proequipmentcorppur.asset.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.math.BigDecimal;
import java.util.Date;

/**
 * 固定资产报废明细表（设备报废申请子表）
 * 
 * @author generator
 * 
 */
 @TableName("ejc_proequipmentcorp_asset_scrap_detail")
public class AssetScrapDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="scrap_id")
    private Long scrapId; // 主表id
    @TableField(value="equipment_type_id")
    private Long equipmentTypeId; // 设备分类id
    @TableField(value="equipment_type_code")
    private String equipmentTypeCode; // 设备分类编码
    @TableField(value="equipment_type_name")
    private String equipmentTypeName; // 设备分类名称
    @TableField(value="equipment_id")
    private Long equipmentId; // 设备id
    @TableField(value="equipment_code")
    private String equipmentCode; // 设备编码
    @TableField(value="equipment_name")
    private String equipmentName; // 设备名称
    @TableField(value="asset_id")
    private Long assetId; // 资产id
    @TableField(value="asset_code")
    private String assetCode; // 资产编码
    @TableField(value="asset_name")
    private String assetName; // 资产名称
    @TableField(value="finance_asset_id")
    private Long financeAssetId; // 财务资产id
    @TableField(value="finance_asset_code")
    private String financeAssetCode; // 财务资产编码
    @TableField(value="spec")
    private String spec; // 规格型号
    @TableField(value="unit_id")
    private Long unitId; // 计量单位 Id
    @TableField(value="unit")
    private String unit; // 计量单位
    @TableField(value="use_unit_id")
    private Long useUnitId; // 使用单位id
    @TableField(value="use_unit")
    private String useUnit; // 使用单位
    @TableField(value="leave_factory_date")
    private Date leaveFactoryDate; // 设备出厂日期
    @TableField(value="original_value")
    private BigDecimal originalValue; // 原值(无税)
    @TableField(value="original_value_tax")
    private BigDecimal originalValueTax; // 原值(含税)
    @TableField(value="net_worth")
    private BigDecimal netWorth; // 净值(无税)
    @TableField(value="net_worth_tax")
    private BigDecimal netWorthTax; // 净值(含税)
    @TableField(value="original_value_price")
    private BigDecimal originalValuePrice; // 原值单价(无税)
    @TableField(value="original_value_price_tax")
    private BigDecimal originalValuePriceTax; // 原值单价(含税)
    @TableField(value="residual_value_tax")
    private BigDecimal residualValueTax; // 残值(含税)
    @TableField(value="residual_value")
    private BigDecimal residualValue; // 残值(无税)
    @TableField(value="last_depreciation_mny")
    private BigDecimal lastDepreciationMny; // 累计折旧金额
    @TableField(value="last_depreciation_tax_mny")
    private BigDecimal lastDepreciationTaxMny; // 累计折旧金额（含税）
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="property_unit_id")
    private Long propertyUnitId; // 产权单位id
    @TableField(value="property_unit")
    private String propertyUnit; // 产权单位
    @TableField(value="manage_unit_id")
    private Long manageUnitId; // 管理单位id
    @TableField(value="manage_unit")
    private String manageUnit; // 管理单位
    @TableField(value="leave_factory_code")
    private String leaveFactoryCode; // 出厂编号
    
    

    public Long getScrapId() {
        return scrapId;
    }

    public void setScrapId(Long scrapId) {
        this.scrapId = scrapId;
    }
    public Long getEquipmentTypeId() {
        return equipmentTypeId;
    }

    public void setEquipmentTypeId(Long equipmentTypeId) {
        this.equipmentTypeId = equipmentTypeId;
    }
    public String getEquipmentTypeCode() {
        return equipmentTypeCode;
    }

    public void setEquipmentTypeCode(String equipmentTypeCode) {
        this.equipmentTypeCode = equipmentTypeCode;
    }
    public String getEquipmentTypeName() {
        return equipmentTypeName;
    }

    public void setEquipmentTypeName(String equipmentTypeName) {
        this.equipmentTypeName = equipmentTypeName;
    }
    public Long getEquipmentId() {
        return equipmentId;
    }

    public void setEquipmentId(Long equipmentId) {
        this.equipmentId = equipmentId;
    }
    public String getEquipmentCode() {
        return equipmentCode;
    }

    public void setEquipmentCode(String equipmentCode) {
        this.equipmentCode = equipmentCode;
    }
    public String getEquipmentName() {
        return equipmentName;
    }

    public void setEquipmentName(String equipmentName) {
        this.equipmentName = equipmentName;
    }
    public Long getAssetId() {
        return assetId;
    }

    public void setAssetId(Long assetId) {
        this.assetId = assetId;
    }
    public String getAssetCode() {
        return assetCode;
    }

    public void setAssetCode(String assetCode) {
        this.assetCode = assetCode;
    }
    public String getAssetName() {
        return assetName;
    }

    public void setAssetName(String assetName) {
        this.assetName = assetName;
    }
    public Long getFinanceAssetId() {
        return financeAssetId;
    }

    public void setFinanceAssetId(Long financeAssetId) {
        this.financeAssetId = financeAssetId;
    }
    public String getFinanceAssetCode() {
        return financeAssetCode;
    }

    public void setFinanceAssetCode(String financeAssetCode) {
        this.financeAssetCode = financeAssetCode;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public Long getUnitId() {
        return unitId;
    }

    public void setUnitId(Long unitId) {
        this.unitId = unitId;
    }
    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }
    public Long getUseUnitId() {
        return useUnitId;
    }

    public void setUseUnitId(Long useUnitId) {
        this.useUnitId = useUnitId;
    }
    public String getUseUnit() {
        return useUnit;
    }

    public void setUseUnit(String useUnit) {
        this.useUnit = useUnit;
    }
    public Date getLeaveFactoryDate() {
        return leaveFactoryDate;
    }

    public void setLeaveFactoryDate(Date leaveFactoryDate) {
        this.leaveFactoryDate = leaveFactoryDate;
    }
    public BigDecimal getOriginalValue() {
        return originalValue;
    }

    public void setOriginalValue(BigDecimal originalValue) {
        this.originalValue = originalValue;
    }
    public BigDecimal getOriginalValueTax() {
        return originalValueTax;
    }

    public void setOriginalValueTax(BigDecimal originalValueTax) {
        this.originalValueTax = originalValueTax;
    }
    public BigDecimal getNetWorth() {
        return netWorth;
    }

    public void setNetWorth(BigDecimal netWorth) {
        this.netWorth = netWorth;
    }
    public BigDecimal getNetWorthTax() {
        return netWorthTax;
    }

    public void setNetWorthTax(BigDecimal netWorthTax) {
        this.netWorthTax = netWorthTax;
    }
    public BigDecimal getOriginalValuePrice() {
        return originalValuePrice;
    }

    public void setOriginalValuePrice(BigDecimal originalValuePrice) {
        this.originalValuePrice = originalValuePrice;
    }
    public BigDecimal getOriginalValuePriceTax() {
        return originalValuePriceTax;
    }

    public void setOriginalValuePriceTax(BigDecimal originalValuePriceTax) {
        this.originalValuePriceTax = originalValuePriceTax;
    }
    public BigDecimal getResidualValueTax() {
        return residualValueTax;
    }

    public void setResidualValueTax(BigDecimal residualValueTax) {
        this.residualValueTax = residualValueTax;
    }
    public BigDecimal getResidualValue() {
        return residualValue;
    }

    public void setResidualValue(BigDecimal residualValue) {
        this.residualValue = residualValue;
    }
    public BigDecimal getLastDepreciationMny() {
        return lastDepreciationMny;
    }

    public void setLastDepreciationMny(BigDecimal lastDepreciationMny) {
        this.lastDepreciationMny = lastDepreciationMny;
    }
    public BigDecimal getLastDepreciationTaxMny() {
        return lastDepreciationTaxMny;
    }

    public void setLastDepreciationTaxMny(BigDecimal lastDepreciationTaxMny) {
        this.lastDepreciationTaxMny = lastDepreciationTaxMny;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    public Long getPropertyUnitId() {
        return propertyUnitId;
    }

    public void setPropertyUnitId(Long propertyUnitId) {
        this.propertyUnitId = propertyUnitId;
    }

    public String getPropertyUnit() {
        return propertyUnit;
    }

    public void setPropertyUnit(String propertyUnit) {
        this.propertyUnit = propertyUnit;
    }

    public Long getManageUnitId() {
        return manageUnitId;
    }

    public void setManageUnitId(Long manageUnitId) {
        this.manageUnitId = manageUnitId;
    }

    public String getManageUnit() {
        return manageUnit;
    }

    public void setManageUnit(String manageUnit) {
        this.manageUnit = manageUnit;
    }

    public String getLeaveFactoryCode() {
        return leaveFactoryCode;
    }

    public void setLeaveFactoryCode(String leaveFactoryCode) {
        this.leaveFactoryCode = leaveFactoryCode;
    }
}
